# Buxon, a sioc:Forum Visor
#
# SWAML <http://swaml.berlios.de/>
# Semantic Web Archive of Mailing Lists
#
# Copyright (C) 2006-2008 Sergio Fernández, Diego Berrueta
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTIBILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.

__author__       = 'Sergio Fernández <http://www.wikier.org/>'
__contributors__ = ['Diego Berrueta <http://www.berrueta.net/>',
                    'Jose Emilio Labra <http://www.di.uniovi.es/~labra/>']
__copyright__    = 'Copyright 2005-2008, Sergio Fernández'
__license__      = 'GNU General Public License'
__version__      = '0.0.4'
__url__          = 'http://swaml.berlios.de/'
__agent__        = 'http://swaml.berlios.de/doap.rdf'

